@@ -40,6 +40,7 @@ class Pod(NamespacedResource):
         priority_class_name: str | None = None,
         readiness_gates: list[Any] | None = None,
         resource_claims: list[Any] | None = None,
+        resources: dict[str, Any] | None = None,
         restart_policy: str | None = None,
         runtime_class_name: str | None = None,
         scheduler_name: str | None = None,
@@ -211,6 +212,8 @@ class Pod(NamespacedResource):
               This is an alpha field and requires enabling the
               DynamicResourceAllocation feature gate.  This field is immutable.
 
+            resources (dict[str, Any]): ResourceRequirements describes the compute resource requirements.
+
             restart_policy (str): Restart policy for all containers within the pod. One of Always,
               OnFailure, Never. In some contexts, only a subset of those values
               may be permitted. Default to Always. More info:
@@ -253,8 +256,8 @@ class Pod(NamespacedResource):
               means setting the FQDN in the hostname field of the kernel (the
               nodename field of struct utsname). In Windows containers, this
               means setting the registry value of hostname for the registry key
-              HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Services\Tcpip\Paramet
-              ers to FQDN. If a pod does not have FQDN, this has no effect.
+              HKEY_LOCAL_MACHINE\\SYSTEM\\CurrentControlSet\\Services\\Tcpip\\Pa
+              rameters to FQDN. If a pod does not have FQDN, this has no effect.
               Default to false.
 
             share_process_namespace (bool): Share a single process namespace between all of the containers in a
@@ -317,6 +320,7 @@ class Pod(NamespacedResource):
         self.priority_class_name = priority_class_name
         self.readiness_gates = readiness_gates
         self.resource_claims = resource_claims
+        self.resources = resources
         self.restart_policy = restart_policy
         self.runtime_class_name = runtime_class_name
         self.scheduler_name = scheduler_name
@@ -416,6 +420,9 @@ class Pod(NamespacedResource):
             if self.resource_claims is not None:
                 _spec["resourceClaims"] = self.resource_claims
 
+            if self.resources is not None:
+                _spec["resources"] = self.resources
+
             if self.restart_policy is not None:
                 _spec["restartPolicy"] = self.restart_policy
 
